OC.L10N.register(
    "core",
    {
    "Please select a file." : "من فضلك حدد الملف",
    "File is too big" : "حجم الملف أكبر من المسموح",
    "The selected file is not an image." : "الملف المحدد ليس صورة ",
    "The selected file cannot be read." : "الملف المحدد لا يمكن قرأته",
    "The file was uploaded" : "تم رفع الملف",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم الملف المرفوع قد تجاوز  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد رفعه أعلى من الحد المسموح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "تم رفع الملف بشكل جزئي فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "تعذر نسخ الملف الى القرص",
    "A PHP extension stopped the file upload" : "أوقف امتداد PHP تحميل الملف",
    "Invalid file provided" : "تم تقديم ملف غير صالح",
    "No image or file provided" : "لم يتم توفير صورة أو ملف",
    "Unknown filetype" : "نوع الملف غير معروف",
    "An error occurred. Please contact your admin." : "حدث خطأ، يرجى مراجعة المسؤول.",
    "Invalid image" : "الصورة غير صالحة",
    "No temporary profile picture available, try again" : "لا تتوفر صورة ملف شخصي مؤقتة، حاول مرة أخرى",
    "No crop data provided" : "لم يتم تحديد قص البيانات.",
    "No valid crop data provided" : "تحديد قص البيانات غير صحيح.",
    "Crop is not square" : "القص ليس مربعا",
    "State token does not match" : "حالة Token غير مطابقة",
    "Invalid app password" : "كلمة المرور للتطبيق غير صحيحه",
    "Could not complete login" : "لا يمكن إكمال عملية تسجيل الدخول",
    "State token missing" : "قيمة الحالة state token غير موجودة",
    "Your login token is invalid or has expired" : "معلومات الجلسة غير صالحة أو منتهية",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "هذا الإصدار المجتمعي من نكست كلاود غير مدعوم و إشعارات الدفع محدودة.",
    "Login" : "الدخول",
    "Unsupported email length (>255)" : "طول رسالة الإيميل يتعدى المسموح (أكبر من 255 حرفاً)",
    "Password reset is disabled" : "تم تعطيل إعادة تعيين كلمة المرور",
    "Could not reset password because the token is expired" : "لا يمكن إعادة تعيين كلمة المرور بسبب انتهاء صلاحية الجلسة.",
    "Could not reset password because the token is invalid" : "لا يمكن إعادة تعيين كلمة المرور بسبب خطأ في تكوين الجلسة",
    "Password is too long. Maximum allowed length is 469 characters." : "كلمة المرور طويلة جداً. أقصى طول مسموح به هو 469 حرفاً.",
    "%s password reset" : "%s إعادة تعيين كلمة مرور ",
    "Password reset" : "إعادة تعيين كلمة مرور",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "اضغط على الزر بالاسفل لإعادة تعيين كلمة المرور. إذا لم تطلب إعادة تعيين كلمة المرور، يرجى تجاهل هذه الرسالة.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "اضغط على الزر بالاسفل لإعادة تعيين كلمة المرور. إذا لم تطلب إعادة تعيين كلمة المرور، يرجى تجاهل هذه الرسالة.",
    "Reset your password" : "أعد تعيين كلمة المرور",
    "The given provider is not available" : "المُزوِّد المحدد غير متوفر",
    "Task not found" : "تعذّر العثور على المُهِمَّة",
    "Internal error" : "خطأ داخلي",
    "Not found" : "غير موجود",
    "Bad request" : "طلب غير جيد",
    "Requested task type does not exist" : "لا توجد مهام من النوع المطلوب",
    "Necessary language model provider is not available" : "مزود نموذج اللغة language model provider ضروري لكنه غير متوفر",
    "No text to image provider is available" : "لا يوجد أي مٌزوِّد لتحويل النصوص إلى صور",
    "Image not found" : "الصورة غير موجودة",
    "No translation provider available" : "لا توجد خدمة للترجمة",
    "Could not detect language" : "لم يُمكن اكتشاف اللغة",
    "Unable to translate" : "لم يُمكن الترجمة",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair step:" : "خطوة صيانة:",
    "Repair info:" : "معلومات صيانة:",
    "Repair warning:" : "تحذير صيانة:",
    "Repair error:" : "خطأ صيانة:",
    "Nextcloud Server" : "خادم نكست كلاود",
    "Some of your link shares have been removed" : "تم ازالة البعض من مشاركة الروابط الخاصة بك.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "نظرا لسبب آمني تم ازالة البعض من روابط المشاركة الخاصة بك. يرجى مراجعة الرابط التالي لمزيد من التفاصيل.",
    "The account limit of this instance is reached." : "تم الوصول إلى الحد الأقصى من الحسابات على هذا الخادم",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "أدخِل مفتاح الاشتراك الخاص بك في تطبيق الدعم لزيادة حد الأقصى من الحسابات. يمنحك هذا أيضًا جميع المزايا الإضافية التي يقدمها Nextcloud Enterprise ويوصى به بشدة للشركات و المؤسسات.",
    "Learn more ↗" : "تعلم المزيد ↗",
    "Preparing update" : "جارٍ تهيئة التحديث",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "يرجى الترقية من خلال سطر الأوامر command line updater حيث أن الترقية من المستعرض معطلة في ملف config.php.",
    "Turned on maintenance mode" : "تشغيل وضع الصيانة.",
    "Turned off maintenance mode" : "تعطيل وضع الصيانة.",
    "Maintenance mode is kept active" : "لم يزل وضع الصيانة نشط",
    "Updating database schema" : "يحدث مخطط قاعدة البيانات",
    "Updated database" : "قاعدة بيانات محدثة",
    "Update app \"%s\" from App Store" : "قم بتحديث التطبيق \"%s\" عن طريق متجر التطبيقات",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "جاري فحص إذا كان مخطط قاعدة البيانات لـ %s يمكن تحديثه (قد يستغرق ذلك بعض الوقت اعتمادًا على مساحة قاعدة البيانات)",
    "Updated \"%1$s\" to %2$s" : "حدث \"%1$s\" إلى %2$s",
    "Set log level to debug" : "أعد تعيين مستوى السجلات إلى اكتشاف الاخطاء المفصلة",
    "Reset log level" : "أعد تعيين مستوى السجلات",
    "Starting code integrity check" : "البدء في فحص دمج الاكواد",
    "Finished code integrity check" : "انتهى فحص دمج الاكواد",
    "%s (incompatible)" : "%s (غير متوافق)",
    "The following apps have been disabled: %s" : "التطبيقات التاليه غير مفعله: %s",
    "Already up to date" : "محدّثة مسبقاً",
    "Unknown" : "غير معروف",
    "PNG image" : "صورة PNG",
    "unknown text" : "النص غير معروف",
    "Hello world!" : "مرحبا بالعالم!",
    "sunny" : "مشمس",
    "Hello {name}, the weather is {weather}" : "مرحبًا {name}، حالة الطقس {weather}",
    "Hello {name}" : "مرحبا {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>هذه هي نتائج البحث الخاصة بك <script>تنبيه(1)</script> </strong>",
    "new" : "جديد",
    "_download %n file_::_download %n files_" : ["تنزيل %n ملف","تنزيل ملف واحد","تنزيل ملفين","تنزيل %n ملفات","تنزيل %n ملفات","تنزيل %n ملفات"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "جاري التحديث، وقد يؤدي مغادرة هذه الصفحة إلى توقف العملية في بعض الاحيان.",
    "Update to {version}" : "التحديث إلى {version}",
    "An error occurred." : "حدث خطأ.",
    "Please reload the page." : "رجاء أعد تحميل الصفحة.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "فشل التحديث. لمزيد من المعلومات <a href=\"{url}\"> تصفح مقالات المنتدى الخاص بنا </a> لإصلاح هذا الخطأ.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "فشل التحديث. يرجى التبليغ عن هذه المشكلة إلى <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> مجتمع Nextcloud </a>.",
    "Continue to {productName}" : "أكمل إلى {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال%n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني."],
    "Applications menu" : "قائمة التطبيقات",
    "Apps" : "التطبيقات",
    "More apps" : "المزيد من التطبيقات",
    "_{count} notification_::_{count} notifications_" : ["{count} إخطارات","{count} إخطارات","{count} إخطارات","{count} إخطارات","{count} إخطارات","{count} إخطارات"],
    "No" : "لا",
    "Yes" : "نعم",
    "The remote URL must include the user." : "عنوان URL  القَصِي يجب أن يحتوي على المستخدِم.",
    "Invalid remote URL." : "عنوان URL البعيد غير صحيح.",
    "Failed to add the public link to your Nextcloud" : "فشل في إضافة الرابط العام إلى الخادم السحابي الخاص بك",
    "Federated user" : "مستخدم السحابة الموحدة",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "إنشاء مشاركة",
    "Please copy the link manually:" : "يرجى نسخ الرابط يدوياً:",
    "Custom date range" : "نطاق زمني مخصص",
    "Pick start date" : "إختر تاريخ البدء",
    "Pick end date" : "إختر تاريخ الانتهاء",
    "Search in date range" : "بحث في نطاق التواريخ",
    "Search in current app" : "البحث في التطبيق الحالي",
    "Clear search" : "مَحوُ البحث",
    "Search everywhere" : "البحث الشامل",
    "Searching …" : "يتم الآن البحث…",
    "Start typing to search" : "اكتب هنا للبحث",
    "No matching results" : "لا توجد نتائج مطابقة",
    "Today" : "اليوم",
    "Last 7 days" : "آخر 7 أيام",
    "Last 30 days" : "آخر 30 يوماً",
    "This year" : "هذه السنة",
    "Last year" : "العام الماضي",
    "Unified search" : "البحث الموحد",
    "Search apps, files, tags, messages" : "البحث في التطبيقات والملفات والوسوم والرسائل",
    "Places" : "الموقع",
    "Date" : "التاريخ",
    "Search people" : "البحث عن أشخاص",
    "People" : "الأشخاص",
    "Filter in current view" : "تصفية في المنظور الحالي",
    "Results" : "النتائج ",
    "Load more results" : " عرض المزيد من النتائج",
    "Search in" : "بحث في",
    "Log in" : "تسجيل الدخول",
    "Logging in …" : "تسجيل الدخول …",
    "Log in to {productName}" : "تسجيل الدخول إلى {productName}",
    "Wrong login or password." : "معرف الدخول أو كلمة مرور خاطئة.",
    "This account is disabled" : "هذا الحساب معطل",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "لقد اكتشفنا عدة محاولات تسجيل دخول غير صالحة من عنوان IP الخاص بك. لذلك تم تقييد تسجيل الدخول التالي الخاص بك حتى 30 ثانية.",
    "Account name or email" : "اسم الحساب أو البريد الالكتروني",
    "Account name" : "اسم الحساب",
    "Server side authentication failed!" : "رفض الخادم المصادقة!",
    "Please contact your administrator." : "يرجى التواصل مع مسؤول النظام.",
    "Session error" : "خطأ في الجلسة",
    "It appears your session token has expired, please refresh the page and try again." : "يبدو أن أَمَارَة جلستك قد انتهت صلاحيتها. رجاءً، حدِّث الصفحة ثم حاول مرة أخرى.",
    "An internal error occurred." : "حدث خطأ داخلي.",
    "Please try again or contact your administrator." : "حاول مجددا أو تواصل مع مسؤول النظام.",
    "Password" : "كلمة المرور",
    "Log in with a device" : "سجل دخولك عن طريق جهاز",
    "Login or email" : "تسجيل الدخول أو البريد الإلكتروني",
    "Your account is not setup for passwordless login." : "لم يتم إعداد حسابك لتسجيل الدخول بدون كلمة مرور.",
    "Your connection is not secure" : "اتصالك غير آمن",
    "Passwordless authentication is only available over a secure connection." : "المصادقة بدون كلمة مرور متاحة فقط عبر اتصال آمن.",
    "Browser not supported" : "المتصفح غير مدعوم",
    "Passwordless authentication is not supported in your browser." : "المصادقة بدون كلمة مرور غير مدعومة في متصفحك.",
    "Reset password" : "تعديل كلمة السر",
    "Back to login" : "العودة إلى تسجيل الدخول",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "إذا كان هذا الحساب موجودًا، فسيتم إرسال رسالة إعادة تعيين كلمة المرور إلى عنوان البريد الإلكتروني الخاص به. إذا لم تستلمها، فتحقق من عنوان بريدك الإلكتروني و/أو تسجيل الدخول، وتحقق من مجلدات البريد العشوائي عندك أو اطلب المساعدة من مسؤول النظام لديك.",
    "Couldn't send reset email. Please contact your administrator." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. يرجى مراجعة المسؤول.",
    "Password cannot be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تواصل مع مسؤول النظام.",
    "New password" : "كلمات سر جديدة",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "المحتوى الخاص بك مشفر. لن تكون هناك طريقة لاستعادة محتوياتك وبياناتك بعد إعادة تعيين كلمة مرورك. إذا لم تكن متأكدًا مما يجب فعله ، فيرجى الاتصال بالمسؤول قبل المتابعة. هل حقا تريد الاستمرار؟",
    "I know what I'm doing" : "أعرف ماذا أفعل",
    "Resetting password" : "إعادة تعيين كلمة المرور",
    "Schedule work & meetings, synced with all your devices." : "قم بجدولة العمل والإجتماعات ، بالتزامن مع جميع أجهزتك.",
    "Keep your colleagues and friends in one place without leaking their private info." : "احتفظ بزملائك وأصدقائك في مكان واحد دون تسريب معلوماتهم الخاصة.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "تطبيق بريد إلكتروني بسيط متوافق بشكل ممتاز مع الملفات وجهات الاتصال والتقويم.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "الدردشة، ومكالمات الفيديو، ومشاركة الشاشة، والاجتماعات عبر الإنترنت، ومؤتمرات الويب - في متصفحك ومع تطبيقات الهاتف المحمول.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "مستندات و جداول و عروض تعاونية، بناءً على تطبيق كولابورا Collabora Online.",
    "Distraction free note taking app." : "تطبيق تسجيل الملاحظات دون تشتيت",
    "Recommended apps" : "التطبيقات المستحسنة",
    "Loading apps …" : "تحميل التطبيقات…",
    "Could not fetch list of apps from the App Store." : "لا يمكن العثور على قائمة التطبيقات من متجر التطبيقات.",
    "App download or installation failed" : "فشل تحميل أو تثبيت التطبيق ",
    "Cannot install this app because it is not compatible" : "لا يمكن تثبيت هذا التطبيق لانه غير متوافق",
    "Cannot install this app" : "لا يمكن تثبيت هذا التطبيق",
    "Skip" : "تخطي",
    "Installing apps …" : "جاري تثبيت التطبيقات…",
    "Install recommended apps" : "ثبت التطبيقات الاضافيه",
    "Avatar of {displayName}" : "صورة الملف الشخصي الرمزية لـ {displayName}",
    "Settings menu" : "قائمة الإعدادات",
    "Loading your contacts …" : "تحميل جهات الإتصال",
    "Looking for {term} …" : "جاري البحث عن {term}",
    "Search contacts" : "بحث جهات الاتصال",
    "Reset search" : "إعادة تعيين البحث",
    "Search contacts …" : "البحث عن جهات الإتصال",
    "Could not load your contacts" : "تعذر تحميل جهات الإتصال",
    "No contacts found" : "لم يعثر على جهات اتصال",
    "Show all contacts" : "إظهار كافة جهات الإتصال",
    "Install the Contacts app" : "تثبيت تطبيق جهات الإتصال",
    "Search" : "البحث",
    "No results for {query}" : "لا يوجد ناتج لـ {query}",
    "Press Enter to start searching" : "يرجى الضغط على Enter لبدء البحث",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength}  أو أكثر للبحث"],
    "An error occurred while searching for {type}" : "حدث خطأ أثناء البحث عن {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "يبدأ البحث بمجرد أن تبدأ الكتابة. و يمكنك الوصول إلى النتيجة بمفاتيح الأسهم",
    "Search for {name} only" : "البحث عن {name} فقط",
    "Loading more results …" : "جاري عرض المزيد من النتائج…",
    "Forgot password?" : "هل نسيت كلمة السر ؟",
    "Back to login form" : "عودة إلى نموذج الدخول",
    "Back" : "العودة",
    "Login form is disabled." : "نموذج تسجيل الدخول معطل",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "نموذج تسجيل الدخول إلى نكست كلاود مُعطّل. استخدم خيار تسجيل دخول آخر إذا كان متاحًا أو اتصل بمسؤول النظام.",
    "More actions" : "إجراءات إضافية",
    "Password is too weak" : "كلمة المرور ضعيفة جدّاً",
    "Password is weak" : "كلمة المرور ضعيفة",
    "Password is average" : "كلمة المرور متوسطة القوة",
    "Password is strong" : "كلمة المرور قوية",
    "Password is very strong" : "كلمة المرور قوية جدّاً",
    "Password is extremely strong" : "كلمة المرور قوية جدّاً جدّاً",
    "Unknown password strength" : "يتعذّر تقييم قوة كلمة المرور ",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "على الأرجح أن بيانات ملفاتك ومجلداتك يمكن الوصول إليها من الإنترنت لأن الملف <code>.htaccess</code>لايعمل.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "لمعلومات أكثر حول كيفية تهيئة خادومك، رجاءً،{linkStart}أنظُر التوثيق {linkEnd}",
    "Autoconfig file detected" : "تمّ اكتشاف ملف التهيئة التلقائية Autoconfig",
    "The setup form below is pre-filled with the values from the config file." : "نموذج الإعدادات أدناه تمّت تعبئته بقيم من ملف التهيئة.",
    "Security warning" : "تحذير الأمان",
    "Create administration account" : "إنشاء حساب إدارة",
    "Administration account name" : "اسم حساب الإدارة",
    "Administration account password" : "كلمة مرور حساب الإدارة",
    "Storage & database" : "التخزين و قاعدة البيانات",
    "Data folder" : "مجلد المعلومات",
    "Database configuration" : "تهيئة قاعدة البيانات",
    "Only {firstAndOnlyDatabase} is available." : "فقط {firstAndOnlyDatabase} متوفرة.",
    "Install and activate additional PHP modules to choose other database types." : "ثبت وفعل مودلات PHP اضافية لاستخدام قاعدة بيانات مختلفة.",
    "For more details check out the documentation." : "للمزيد من التفاصيل، يرجى الإطلاع على الدليل.",
    "Performance warning" : "تحذير حول الأداء",
    "You chose SQLite as database." : "لقد اخترت SQLite كقاعدة بيانات.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "يجب استخدام SQLite فقط في حالات الحد الأدنى من التطوير. للنسخة النهائية، نوصي باستخدام خلفية قاعدة بيانات مختلفة.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "إذا كنت تستخدم عملاء لمزامنة الملفات ، فإن استخدام SQLite لا ينصح به بشدة.",
    "Database user" : "مستخدم قاعدة البيانات",
    "Database password" : "كلمة سر مستخدم قاعدة البيانات",
    "Database name" : "اسم قاعدة البيانات",
    "Database tablespace" : "مساحة جدول قاعدة البيانات",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "يرجى تحديد رقم المنفذ مع اسم المضيف (على سبيل المثال ، mycloud:5432).",
    "Database host" : "خادم قاعدة البيانات",
    "localhost" : "localhost جهازك المُضِيف المحلي",
    "Installing …" : "جاري التثبيت...",
    "Install" : "تثبيت",
    "Need help?" : "تحتاج إلى مساعدة؟",
    "See the documentation" : "اطلع على التعليمات",
    "{name} version {version} and above" : "المستعرض {name} من النسخة {version} فما فوق",
    "This browser is not supported" : "المستعرض غير مدعوم",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "المستعرض غير مدعوم. رجاءً قم بالترقية إلى نسخة أحدث أو إلى  مستعرض آخر مدعوم.",
    "Continue with this unsupported browser" : "إستمر مع هذا المستعرض غير المدعوم",
    "Supported versions" : "النسخ المدعومة",
    "Search {types} …" : "بحث {types} …",
    "Choose {file}" : "إختر {file}",
    "Choose" : "اختيار",
    "Copy to {target}" : "أُنسُخ إلى {target}",
    "Copy" : "نسخ",
    "Move to {target}" : "أُنقُل إلى {target}",
    "Move" : "نقل",
    "OK" : "موافق",
    "read-only" : "قراءة فقط",
    "_{count} file conflict_::_{count} file conflicts_" : ["لا يوجد تعارض","{count} ملف متعارض","ملفان متعارضان","{count} ملفات متعارضة"," {count} ملفا متعارضا","{count} ملفات متعارضه"],
    "One file conflict" : "تعارض ملف واحد",
    "New Files" : "ملفات جديدة",
    "Already existing files" : "المفات موجودة مسبقاً",
    "Which files do you want to keep?" : "ماهي الملفات التي ترغب في إبقاءها ؟",
    "If you select both versions, the copied file will have a number added to its name." : "عند إختيار كلا النسختين. المف المنسوخ سيحتوي على رقم في إسمه.",
    "Cancel" : "إلغاء",
    "Continue" : "المتابعة",
    "(all selected)" : "(إختيار الكل)",
    "({count} selected)" : "({count} تم تحديد)",
    "Error loading file exists template" : "خطأ في تحميل القالب الحالي",
    "Saving …" : "جاري الحفظ…",
    "seconds ago" : "منذ ثواني",
    "Connection to server lost" : "تم فقد الاتصال بالخادم",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثانية","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني."],
    "Add to a project" : "إضافة إلى مشروع",
    "Show details" : "عرض التفاصيل",
    "Hide details" : "إخفاء التفاصيل",
    "Rename project" : "إعادة تسمية المشروع",
    "Failed to rename the project" : "فشل في إعادة تسمية المشروع",
    "Failed to create a project" : "فشل في إنشاء مشروع",
    "Failed to add the item to the project" : "فشل في إضافة المحتوى إلى المشروع",
    "Connect items to a project to make them easier to find" : "اربط المحتوى إلى المشروع للوصول إليه بسهوله",
    "Type to search for existing projects" : "اكتب هنا للبحث عن مشاريع مسجلة",
    "New in" : "الجديد في",
    "View changelog" : "اعرض سجل التغييرات",
    "No action available" : "لا يتوفر أي إجراء",
    "Error fetching contact actions" : "حدث خطأ أثناء جلب إجراءات جهات الاتصال",
    "Close \"{dialogTitle}\" dialog" : "أغلق الحوار \"{dialogTitle}\"",
    "Email length is at max (255)" : "طول رسالة الإيميل وصل أقصى المسموح ( 255)",
    "Non-existing tag #{tag}" : "وسم غير موجود #{tag}",
    "Restricted" : "مقيد",
    "Invisible" : "مخفي",
    "Delete" : "إلغاء",
    "Rename" : "إعادة التسمية",
    "Collaborative tags" : "أوسمة تعاونية",
    "No tags found" : "لم يُعثَر على أي وسم",
    "Clipboard not available, please copy manually" : "الحافظة غير متاحة. رجاءً، قم بالنسخ يدويّاً",
    "Personal" : "شخصي",
    "Accounts" : "الحسابات",
    "Admin" : "المدير",
    "Help" : "المساعدة",
    "Access forbidden" : "الوصول محظور",
    "Back to %s" : "العودة إلى %s",
    "Page not found" : "الصفحة غير موجودة",
    "The page could not be found on the server or you may not be allowed to view it." : "لم يُمكن إيجاد الصفحة على الخادم أو ربما غير مسموح لك بالوصول إليها.",
    "Too many requests" : "الطلبات أقصى من الحد المسموح",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "يوجد طلبات أقصى من الحد المسموح به في الشبكة. أعد المحاولة أو اتصل بمسؤول النظام.",
    "Error" : "خطأ",
    "Internal Server Error" : "خطأ داخلي في الخادم",
    "The server was unable to complete your request." : "لا يمكن معالجة طلبك",
    "If this happens again, please send the technical details below to the server administrator." : "إذا حدث هذا مرة أخرى ، يرجى إرسال التفاصيل الفنية أدناه إلى مسؤول الخادم.",
    "More details can be found in the server log." : "مزيد من التفاصيل في سجلات الخادم.",
    "For more details see the documentation ↗." : "لمزيد من المعلومات، أنظر التوثيق ↗.",
    "Technical details" : "تفاصيل تقنية",
    "Remote Address: %s" : "العنوان البعدي : %s",
    "Request ID: %s" : "رقم الطلب: %s",
    "Type: %s" : "النوع : %s",
    "Code: %s" : "الرمز : %s",
    "Message: %s" : "الرسالة : %s",
    "File: %s" : "ملف : %s",
    "Line: %s" : "السطر: %s",
    "Trace" : "متابعة",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "يبدو أنك تحاول إعادة تثبيت نكست كلاود الخاص بك. ومع ذلك ، فإن الملف CAN_INSTALL مفقود من دليل التثبيت الخاص بك. يرجى إنشاء الملف CAN_INSTALL في مجلد التثبيت الخاص بك للمتابعة.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "تعذر إزالة CAN_INSTALL من مجلد التكوين. الرجاء إزالة هذا الملف يدويا.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "هذا التطبيق يتطلب JavaScript ليتم تشغيله بالطريقة الصحيحة. يرجى {linkstart}تفعيل JavaScript{linkend} وتحديث الصفحة.",
    "Skip to main content" : "تخطّيه وانتقل إلى المحتوى الرئيسي",
    "Skip to navigation of app" : "تجاهل التنقل في التطبيق",
    "Go to %s" : "الإنتقال إلى %s",
    "Get your own free account" : "احصل على حساب لك بالمجان",
    "Connect to your account" : "الاتصال بحسابك",
    "Please log in before granting %1$s access to your %2$s account." : "يرجى تسجيل الدخول قبل الحصول على اذن %1$s في حسابك %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "إذا كنت لا تحاول تعيين جهاز أو تطبيق جديد ، فإن شخصًا ما يحاول خداعك لمنحه حق الوصول إلى بياناتك. في هذه الحالة ، لا تقم بالمتابعة وبدلاً من ذلك اتصل بمسؤول النظام.",
    "App password" : "كلمة مرور التطبيق",
    "Grant access" : "السماح بالنفاذ",
    "Alternative log in using app password" : "تسجيل الدخول بطريقة بديلة باستخدام كلمة مرور التطبيق",
    "Account access" : "حساب النفاذ",
    "Currently logged in as %1$s (%2$s)." : "مسجّل حاليّاً كـ %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "انت على وشك الحصول على اذن %1$s لحسابك %2$s.",
    "Account connected" : "الحساب متصل",
    "Your client should now be connected!" : "من المفترض ان عميلك متصل الان!",
    "You can close this window." : "بإمكانك اغلاق النافذة",
    "Previous" : "السابق",
    "This share is password-protected" : "هذه المشاركة محمية بكلمة مرور",
    "The password is wrong or expired. Please try again or request a new one." : "كلمة المرور أمّا غير مُطابقة أو منتهية الصلاحية. رجاءً حاول مرة أخرى أو أطلب واحدة جديدة.",
    "Please type in your email address to request a temporary password" : "رجاءً أدخل عنوان بريدك الالكتروني لطلب كلمة مرور مؤقتة",
    "Email address" : "عنوان البريد الإلكتروني",
    "Password sent!" : "تم إرسال كلمة المرور!",
    "You are not authorized to request a password for this share" : "لست مخولاً لطلب كلمة مرور لهذه المشاركة",
    "Two-factor authentication" : "المصادقة بخطوتين",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "تعزيز الآمان مفعل في حسابك. يرجى اختيار وسيلة ثانية للمصادقة:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "تعذر تحميل طريقة واحدة على الأقل من طرق المصادقة الثنائية الممكّنة. الرجاء الاتصال بالمسؤول الخاص بك.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "يتم فرض المصادقة ذات العاملين ولكن لم يتم تكوينها على حسابك. اتصل بالمسؤول للحصول على المساعدة.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "يتم فرض المصادقة ذات العاملين ولكن لم يتم تكوينها على حسابك. الرجاء متابعة إعداد المصادقة الثنائية.",
    "Set up two-factor authentication" : "تعيين المصادقة بخطوتين",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "يتم فرض المصادقة ذات العاملين ولكن لم يتم تكوينها على حسابك. استخدم أحد الرموز الاحتياطية لتسجيل الدخول أو اتصل بالمسؤول للحصول على المساعدة.",
    "Use backup code" : "إستخدم الرمز الإحتياطي",
    "Cancel login" : "إلغاء تسجيل الدخول",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "تعزيز الآمان مفعل في حسابك. تعيين المشغل للخدمة:",
    "Error while validating your second factor" : "خطأ أثناء التحقق من صحة العامل الثاني الخاص بك",
    "Access through untrusted domain" : "الدخول عبر اسم نطاق غير مسجل",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "يرجى التواصل مع مسؤول النظام. بإمكانك إضافة اسم النطاق في اعدادات ملف config/config.php ضمن الخيار \"trusted_domains\".",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "مزيد من المعلومات تجدها في %1$sدليل الاستخدام%2$s.",
    "App update required" : "تحديث التطبيق مطلوب",
    "%1$s will be updated to version %2$s" : "%1$s سيتم التحديث إلى الاصدار %2$s",
    "The following apps will be updated:" : "التطبيقات التالية سوف يتم تحديثها:",
    "These incompatible apps will be disabled:" : "التطبيقات التالية الغير متوافقه سيتم تعطيلها:",
    "The theme %s has been disabled." : "القالب %s معطل. ",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "يرجى سحب نسخة احتياطية من قاعدة البيانات، مجلد الإعدادات config و مجلد data قبل الاستمرار.",
    "Start update" : "تشغيل التحديث",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "لتتجنب انقطاع الاتصال بسبب التثبيت للمساحات الضخمة، بإمكانك استخدام الامر التالي في مجلد التثبيت:",
    "Detailed logs" : "السجلات المفصلة",
    "Update needed" : "التحديث مطلوب",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "من فضلك، استَعمِل الأمر السطري للتحديث command line updater لأن الخادم كبير يحوي أكثر من 50 حساباً.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "للمساعدة يُرجى الإطلاع على <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">الدليل</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "أقر عن الخطر المحتمل في حال إكمال عملية التحديث عبر واجهة الرسوم في الويب، لربما يفقد اتصال الجلسة وينتهي الوقت المسموح وفقدان البيانات، ولدي نسخة احتياطية واقر بمعرفتي باستعادة البيانات في حال حدوث خطأ في التحديث.",
    "Upgrade via web on my own risk" : "تحديث عبر واجهة الويب على مسؤليتي الشخصية",
    "Maintenance mode" : "وضع الصيانة",
    "This %s instance is currently in maintenance mode, which may take a while." : "هذا %s في وضع الصيانة، قد يستغرق ذلك بعض الوقت.",
    "This page will refresh itself when the instance is available again." : "سوف يتم تحديث الصفحة في حين الخادم جاهز للاستخدام مجددا.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "تواصل مع مسؤول النظام اذا استمرت هذه الرسالة بالظهور دائما أو بشكل مفاجئ.",
    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "الدردشة ومكالمات الفيديو ومشاركة الشاشة والإجتماعات عبر الإنترنت ومؤتمرات الويب - في متصفحك ومع تطبيق للهاتف المحمول.",
    "You have not added any info yet" : "لم تقم بإضافة أي معلومات حتى الآن",
    "{user} has not added any info yet" : "لم يقم المستخدم {user} بإضافة أي معلومات بعد",
    "Error opening the user status modal, try hard refreshing the page" : "خطأ في فتح حالة المستخدم ، حاول تحديث الصفحة",
    "Edit Profile" : "تعديل الملف الشخصي",
    "The headline and about sections will show up here" : "سيظهر هنا العنوان والأقسام الخاصة بالملف الشخصي",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "So-so password" : "كلمة سر غير فعالة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Profile not found" : "ملف المستخدم غير موجود",
    "The profile does not exist." : "الملف الشخصي غير موجود.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "للحصول على معلومات حول كيفية تكوين الخادم الخاص بك، يرجى الاطلاع على <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">التعليمات</a>.",
    "<strong>Create an admin account</strong>" : "<strong>إنشاء حساب مُشرِف</strong>",
    "New admin account name" : "اسم حساب المشرف الجديد",
    "New admin password" : "كلمة مرور المشرف الجديد",
    "Show password" : "اظهر كلمة المرور",
    "Toggle password visibility" : "تبديل قراءة كلمة المرور",
    "Configure the database" : "إعداد قاعدة البيانات",
    "Only %s is available." : "لم يتبقى إلّا %s.",
    "Database account" : "حساب قاعدة البيانات",
    "Direct link copied to clipboard" : "تمّ نسخ الرابط المباشر إلى الحافظة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
